@@ -9,7 +9,9 @@ use base qw( Alzabo::ObjectCache::Sync::DBM );
 use Alzabo::Exceptions;
 use BerkeleyDB qw( DB_CREATE DB_INIT_MPOOL DB_INIT_CDB DB_NOTFOUND DB_NOOVERWRITE DB_KEYEXIST );
 
-$VERSION = sprintf '%2d.%02d', q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/;
+use File::Basename ();
+
+$VERSION = sprintf '%2d.%02d', q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/;
 
 1;
 
@@ -27,9 +29,13 @@ sub import
 	    or Alzabo::Exception::System->throw( error => "Can't delete '$p{sync_dbm_file}': $!" );
     }
 
-    $ENV = BerkeleyDB::Env->new( -Flags => DB_CREATE | DB_INIT_MPOOL | DB_INIT_CDB )
+    my ($filename, $dir, $suffix) = File::Basename::fileparse( $p{sync_dbm_file} );
+    $ENV = BerkeleyDB::Env->new( -Flags => DB_CREATE | DB_INIT_MPOOL | DB_INIT_CDB,
+				 -Home => $dir,
+			       )
 	or Alzabo::Exception->throw( error => "Can't create environment: $BerkeleyDB::Error\n" );
-    $DB = BerkeleyDB::Hash->new( -Filename => $p{sync_dbm_file},
+
+    $DB = BerkeleyDB::Hash->new( -Filename => $filename . $suffix,
 				 -Mode => 0644,
 				 -Env => $ENV,
 				 -Flags => DB_CREATE,
