@@ -6,11 +6,11 @@ use vars qw($VERSION $CACHE);
 use Alzabo::Runtime;
 
 use Params::Validate qw( :all );
-Params::Validate::set_options( on_fail => sub { Alzabo::Exception::Params->throw( error => join '', @_ ) } );
+Params::Validate::validation_options( on_fail => sub { Alzabo::Exception::Params->throw( error => join '', @_ ) } );
 
 use base qw(Alzabo::Runtime::Row);
 
-$VERSION = sprintf '%2d.%02d', q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/;
+$VERSION = sprintf '%2d.%02d', q$Revision: 1.14 $ =~ /(\d+)\.(\d+)/;
 
 1;
 
@@ -137,7 +137,7 @@ sub update
     while (my ($k, $v) = each %data)
     {
 	# These can't be stored until they're fetched from the database again
-	if ( UNIVERSAL::isa( $v, 'Alzabo::SQLMaker::Literal' ) )
+	if ( defined $v && UNIVERSAL::isa( $v, 'Alzabo::SQLMaker::Literal' ) )
 	{
 	    delete $self->{data}{$k};
 	    next;
